"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RenderSnippetParameterHoverProvider = void 0;
const liquid_html_parser_1 = require("@shopify/liquid-html-parser");
const liquidDoc_1 = require("../../utils/liquidDoc");
class RenderSnippetParameterHoverProvider {
    constructor(getSnippetDefinitionForURI) {
        this.getSnippetDefinitionForURI = getSnippetDefinitionForURI;
    }
    async hover(currentNode, ancestors, params) {
        var _a, _b;
        const parentNode = ancestors.at(-1);
        if (currentNode.type !== liquid_html_parser_1.NodeTypes.NamedArgument ||
            !parentNode ||
            parentNode.type !== liquid_html_parser_1.NodeTypes.RenderMarkup ||
            parentNode.snippet.type !== liquid_html_parser_1.NodeTypes.String) {
            return null;
        }
        const snippetName = parentNode.snippet.value;
        const snippetDefinition = await this.getSnippetDefinitionForURI(params.textDocument.uri, snippetName);
        if (!((_b = (_a = snippetDefinition === null || snippetDefinition === void 0 ? void 0 : snippetDefinition.liquidDoc) === null || _a === void 0 ? void 0 : _a.parameters) === null || _b === void 0 ? void 0 : _b.length)) {
            return null;
        }
        const paramName = currentNode.name;
        const hoveredParameter = snippetDefinition.liquidDoc.parameters.find((parameter) => parameter.name === paramName);
        if (!hoveredParameter) {
            return null;
        }
        return {
            contents: {
                kind: 'markdown',
                value: (0, liquidDoc_1.formatLiquidDocParameter)(hoveredParameter, true),
            },
        };
    }
}
exports.RenderSnippetParameterHoverProvider = RenderSnippetParameterHoverProvider;
//# sourceMappingURL=RenderSnippetParameterHoverProvider.js.map